@@ -7,8 +7,14 @@
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 
-pydocstyle invenio_rest tests docs && \
-isort invenio_rest tests --check-only --diff && \
-check-manifest --ignore ".travis-*" && \
-sphinx-build -qnNW docs docs/_build/html && \
-python setup.py test
+# Quit on errors
+set -o errexit
+
+# Quit on unbound symbols
+set -o nounset
+
+pydocstyle invenio_rest tests docs
+isort invenio_rest tests --check-only --diff
+check-manifest --ignore ".*-requirements.txt"
+sphinx-build -qnNW docs docs/_build/html
+pytest
